module.exports = defineTest({
	description: 'removes an empty do-while statement'
});
